summaryrefslogtreecommitdiffstats
path: root/os/tpf/os.c
diff options
context:
space:
mode:
authorRyan Bloom <rbb@apache.org>1999-08-31 07:35:52 +0200
committerRyan Bloom <rbb@apache.org>1999-08-31 07:35:52 +0200
commitc37f14ddf32319a7d84a9b573a54ccde8f37c5ff (patch)
tree1f1dd08b2e53226b3b3363beee02eeb57a8061ca /os/tpf/os.c
parentForgot this hook... (diff)
downloadapache2-c37f14ddf32319a7d84a9b573a54ccde8f37c5ff.tar.xz
apache2-c37f14ddf32319a7d84a9b573a54ccde8f37c5ff.zip
Changed pools to contexts. Tested with prefork and pthread mpm's. I'll
check this out tomorrow and make sure everything was checked in correctly. git-svn-id: https://svn.apache.org/repos/asf/httpd/httpd/trunk@83852 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'os/tpf/os.c')
-rw-r--r--os/tpf/os.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/os/tpf/os.c b/os/tpf/os.c
index e4682324cd..dabe414f0f 100644
--- a/os/tpf/os.c
+++ b/os/tpf/os.c
@@ -57,7 +57,7 @@
/*
* This file will include OS specific functions which are not inlineable.
* Any inlineable functions should be defined in os-inline.c instead.
*/
#include "httpd.h"
@@ -211,7 +211,7 @@ int execvp(const char *file, char *const argv[])
-int ap_tpf_spawn_child(pool *p, int (*func) (void *, child_info *),
+int ap_tpf_spawn_child(ap_context_t *p, int (*func) (void *, child_info *),
void *data, enum kill_conditions kill_how,
int *pipe_in, int *pipe_out, int *pipe_err,
int out_fds[], int in_fds[], int err_fds[])
@@ -222,7 +222,7 @@ int ap_tpf_spawn_child(pool *p, int (*func) (void *, child_info *),
int fd_flags_out, fd_flags_in, fd_flags_err;
struct tpf_fork_input fork_input;
TPF_FORK_CHILD *cld = (TPF_FORK_CHILD *) data;
- array_header *env_arr = ap_table_elts ((array_header *) cld->subprocess_env);
+ ap_array_header_t *env_arr = ap_table_elts ((array_header *) cld->subprocess_env);
table_entry *elts = (table_entry *) env_arr->elts;
@@ -395,7 +395,7 @@ int os_check_server(char *server) {
return 0;
}
-void os_note_additional_cleanups(pool *p, int sd) {
+void os_note_additional_cleanups(ap_context_t *p, int sd) {
char sockfilename[50];
/* write the socket to file so that TPF socket device driver will close socket in case
we happen to abend. */
@@ -57,7 +57,7 @@
/*
* This file will include OS specific functions which are not inlineable.
- * Any inlineable functions should be defined in os-inline.c instead.
+ * Any inlineable functions should be defined in os ap_context_t nline.c instead.
*/
#include "httpd.h"